netapp_ontap.models.maxdata_on_san_application_components API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.maxdata_on_san_application_components`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class MaxdataOnSanApplicationComponentsSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the MaxdataOnSanApplicationComponents object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `file_system GET POST`

    Defines the type of file system that will be installed on this application component.

    Valid choices:

    - generic
    - m1fs
    - xfs
  `host_management_url GET`

    The host management URL for this application component.

  `host_name GET POST`

    FQDN of the L2 host that contains the hot tier of this application component.

  `igroup_name GET POST PATCH`

    The name of the initiator group through which the contents of this application will be accessed. Modification of this parameter is a disruptive operation. All LUNs in the application component will be unmapped from the current igroup and re-mapped to the new igroup.

  `lun_count GET POST PATCH`

    The number of LUNs in the application component.

  `metadata GET POST`

    The metadata field of the maxdata_on_san_application_components.

  `name GET POST PATCH`

    The name of the application component.

  `protection_type GET POST PATCH`

    The protection_type field of the maxdata_on_san_application_components.

  `storage_service GET POST PATCH`

    The storage_service field of the maxdata_on_san_application_components.

  `tiering GET POST PATCH`

    The tiering field of the maxdata_on_san_application_components.

  `total_size GET POST PATCH`

    The total size of the application component, split across the member LUNs. Usage: {<integer>[KB|MB|GB|TB|PB]}